	subroutine tension1der4C1coeff (xx,px,cx,dimx,dim)

!
!   Calculating all de Boor points of the first derivative of the
!   Chebyshev tension spline curve
!
!   INPUT:
!       xx    = rank-one double precision array of size dimx, the
!               increasing array of knots, assumed to fulfill the
!               conditions:
!               xx(1)=xx(2)<xx(3)<...<xx(i)<xx(i+1)<...<xx(dimx-1)=
!               xx(dimx); xx(3),...,xx(dimx-2) is the partition of
!               [xx(1),xx(dimx)]; the associated extended
!               partition T has all interior knots of multiplicity 2,
!               and the boundary points of multiplicity 4
!       px    = rank-one double precision array of size dimx-1, the
!               array of tension parameters, assumed to be
!               nonnegative: px(i)>=0 is the tension parameter on
!               the subinterval [xx(i),xx(i+1));
!               px(1) and px(dimx-1) can be arbitrary
!       dimx  = integer variable, the size of the array xx
!       dim   = integer variable, the extent of the first dimension
!               in the array cx, assumed to be positive
!
!   INPUT and OUTPUT:
!       cx    = rank-two double precision array of shape dim by
!               2*dimx-4;
!               ON INPUT: the array of de Boor points of the
!               Chebyshev tension spline, associated with the
!               extended partition T;
!               cx(1:dim,i) corresponds to the B-spline with the
!               support [T(i),T(i+4)]
!               ON OUTPUT: the array of de Boor points of the
!               first derivative of the Chebyshev tension spline;
!               cx(1:dim,i) corresponds to the B-spline with the
!               support [T(i),T(i+3)] (cx(1:dim,1) will not be used)
!

	use functions

	implicit none

	integer, intent(in) :: dimx,dim
	double precision, intent(in) :: xx(dimx),px(dimx-1)	
	double precision, intent(inout) :: cx(dim,2*dimx-4)

	double precision, parameter :: zero=0.0d0
	double precision :: h(2*dimx-1),p(2*dimx-1)
	integer :: i


!
!   Calculating the length of all subintervals involved and creating
!   the array of tension parameters corresponding to the extended
!   partition T
!
	do i=1,dimx-1
		h(2*i-1)=zero
		h(2*i)=xx(i+1)-xx(i)
		p(2*i-1)=zero
		p(2*i)=px(i)
	enddo
	h(2*dimx-1)=zero
	p(2*dimx-1)=zero
!
!	Calculating the de Boor points of the first derivative
!
	do i=2*dimx-4,2,-1
		cx(1:dim,i)=(cx(1:dim,i)-cx(1:dim,i-1))*2/CC3(h(i),h(i+1),h(i+2),p(i),p(i+1),p(i+2))/ &
					(1.0d0+exp(-p(i+1)*h(i+1)))
	enddo


	end subroutine tension1der4C1coeff